<?xml version='1.0'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:exsl="http://exslt.org/common"
                xmlns:date="http://exslt.org/dates-and-times"
                xmlns:d="http://docbook.org/ns/docbook"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:ng="http://docbook.org/docbook-ng"
                exclude-result-prefixes="ng exsl d date"
                version='1.0'>
  
    <xsl:import href="res:docbook/fo/echa-default-docbook.xsl" />

    <xsl:param name="central.header.text" select="''"/>
	
	<xsl:template name="head.sep.rule">
	  <xsl:param name="sequence"/>
	  <xsl:param name="gentext-key"/>

	  <xsl:if test="$header.rule != 0">
		<xsl:attribute name="border-bottom-width">0.5pt</xsl:attribute>
		<xsl:attribute name="border-bottom-style">solid</xsl:attribute>
		<xsl:attribute name="border-bottom-color">black</xsl:attribute>
	  </xsl:if>
	</xsl:template>
	
	<xsl:template name="foot.sep.rule">
	  <xsl:param name="sequence"/>
	  <xsl:param name="gentext-key"/>

		<xsl:if test="$footer.rule != 0">
		<xsl:attribute name="border-top-width">0.5pt</xsl:attribute>
		<xsl:attribute name="border-top-style">solid</xsl:attribute>
		<xsl:attribute name="border-top-color">black</xsl:attribute>
		</xsl:if>
	</xsl:template>

    <xsl:param name="callout.extensions">1</xsl:param>

    <xsl:output method="xml" indent="no"/>

    <xsl:param name="fop1.extensions" select="1"/>
    <xsl:param name="fop.extensions">0</xsl:param>

    <xsl:param name="tablecolumns.extension">0</xsl:param>

    <xsl:param name="hyphenate">false</xsl:param>
    <xsl:param name="hyphenation-character">-</xsl:param>

    <xsl:param name="alignment">left</xsl:param>
    <xsl:param name="line-height">1.4</xsl:param>
	
    <xsl:param name="paper.type" select="'A4'"/>
	
	<xsl:param name="page.orientation" select="'portrait'"/>

    <xsl:param name="body.font.master">10</xsl:param>
    <xsl:param name="body.font.family" select="'Roboto,Arial Unicode MS'"/>
    <xsl:param name="title.font.family" select="'Roboto,Arial Unicode MS'"/>
    <xsl:param name="monospace.font.family" select="'Roboto,Arial Unicode MS'"/>
    <xsl:param name="symbol.font.family" select="'Roboto,Arial Unicode MS'"/>
    <xsl:param name="dingbat.font.family" select="'Roboto,Arial Unicode MS'"/>
    <xsl:param name="callout.unicode.font" select="'Arial Unicode MS'"/>

    <xsl:param name="header.column.widths">1 4 1</xsl:param>
    <xsl:param name="footer.column.widths">1 0 1</xsl:param>

    <xsl:param name="chapter.autolabel" select="1"/>
    <xsl:param name="section.autolabel" select="1"/>
    <xsl:param name="section.label.includes.component.label" select="1"/>
    <xsl:param name="section.autolabel.max.depth" select="5"/>

    <xsl:param name="toc.section.depth">5</xsl:param>
    <xsl:param name="generate.toc">
        book      toc,title
    </xsl:param>
    
    <!-- hyperlinks -->
	<xsl:param name="ulink.show" select="0"/>
	<xsl:attribute-set name="xref.properties">
        <xsl:attribute name="color">#0000FF</xsl:attribute>
	</xsl:attribute-set>

    <xsl:template name="book.titlepage.verso"/>
    <xsl:template name="book.titlepage.before.verso"/>
    <xsl:template name="book.titlepage.separator"/>

    
    <l:i18n xmlns:l="http://docbook.sourceforge.net/xmlns/l10n/1.0">
        <l:l10n language="en">
            <l:context name="title-numbered">
                <l:template name="chapter" text="%n.&#160;%t"/>
            </l:context>
        </l:l10n>
    </l:i18n>

    <xsl:variable name="front.cover.title" select="/d:book/d:info/d:title"/>
    <xsl:variable name="front.cover.subtitle" select="/d:book/d:info/d:subtitle"/>
    <xsl:variable name="front.cover.content" select="/d:book/d:info/d:cover/d:para"/>
    <xsl:template name="book.titlepage.recto">
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="$front.cover.title"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="$front.cover.subtitle"/>
        <fo:block padding-top="2in">
            <xsl:apply-templates select="$front.cover.content"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="processing-instruction('linebreak')">
        <fo:block/>
    </xsl:template>

    <xsl:template match="processing-instruction('hard-pagebreak')">
        <fo:block break-after='page'/>
    </xsl:template>

    <xsl:template match="d:chapter/*">
        <fo:block start-indent="0pt">
            <xsl:apply-imports/>
        </fo:block>
    </xsl:template>

    <xsl:template match="d:section">
        <fo:block start-indent="0pt">
            <xsl:apply-imports/>
        </fo:block>
    </xsl:template>

    <xsl:template match="d:formalpara/d:title">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:attribute-set name="xref.properties">
        <xsl:attribute name="color">#0000FF</xsl:attribute>
    </xsl:attribute-set>

    <xsl:template match="*[@role='title']">
        <fo:block font-size="15pt" font-weight="bold" padding-top="3pt" margin-top="3pt" text-align="center"
                  white-space-collapse="false">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="d:para[@role='align-right']">
        <fo:block text-align="right">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>	
	
	<xsl:template match="d:para[@role='valign-middle']">
        <fo:block vertical-align="middle">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="d:para[@role='align-center']">
        <fo:block text-align="center">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
	
	<xsl:template match="d:para[@role='customised-align']">
        <fo:block text-align="left" padding-bottom="2pt">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
	
	<xsl:template match="d:para[@role='customised-align-literature-cover']">
        <fo:block text-align="center" margin-top="25pt" padding-bottom="1pt" space-before="0.10em" start-indent="20px" padding-top="10pt">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="d:para[@role='align-justify']">
        <fo:block text-align="justify">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="d:para[@role='blockquote']">
        <fo:block space-before="1em" space-after="1em">
            <xsl:attribute name="start-indent">
                <xsl:value-of select="(count(ancestor::d:para[@role='blockquote']) + 1) * 3"/>
                <xsl:text>em</xsl:text>
            </xsl:attribute>
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@role='bottom3pt']">
        <fo:block padding-top="0pt" margin-top="0pt" margin-bottom="3pt" white-space-collapse="true">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@role='rule']">
        <fo:block>
            <fo:leader leader-length="100%" leader-pattern="rule"></fo:leader>
        </fo:block>
        <fo:block padding-top="5pt">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@role='cover.rule']">
        <fo:block>
            <fo:leader leader-length="100%" leader-pattern="rule"></fo:leader>
        </fo:block>
        <fo:block padding-top="5pt">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@role='cover.i6label']">
        <fo:inline font-weight="bold" font-size="11pt">
            <xsl:value-of select='text()'/>
            <xsl:text>: </xsl:text>
        </fo:inline>
    </xsl:template>

    <xsl:template match="*[@role='cover.i6content']">
        <fo:inline font-size="11pt">
            <xsl:value-of select='text()'/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="*[@role='i6header1']">
        <fo:block font-size="16pt" font-weight="bold" padding-top="3pt" margin-top="3pt" text-align-last='justify'
                  white-space-collapse="false">
            <xsl:apply-templates/>
            <fo:leader leader-length.maximum="5pt"/>
            <fo:leader leader-pattern="rule" vertical-align="middle" color="grey"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@role='i6header2']">
        <fo:block font-size="15pt" font-weight="bold" padding-top="3pt" margin-top="3pt" text-align-last='justify'
                  white-space-collapse="false">
            <xsl:apply-templates/>
            <fo:leader leader-length.maximum="5pt"/>
            <fo:leader leader-pattern="rule" vertical-align="middle" color="grey"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@role='i6header3']">
        <fo:block font-size="14pt" font-weight="bold" padding-top="3pt" margin-top="3pt" text-align-last='justify'
                  white-space-collapse="false">
            <xsl:apply-templates/>
            <fo:leader leader-length.maximum="5pt"/>
            <fo:leader leader-pattern="rule" vertical-align="middle" color="grey"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@role='i6header4']">
        <fo:block font-size="13pt" font-weight="bold" padding-top="3pt" margin-top="3pt" text-align-last='justify'
                  white-space-collapse="false">
            <xsl:apply-templates/>
            <fo:leader leader-length.maximum="5pt"/>
            <fo:leader leader-pattern="rule" vertical-align="middle" color="grey"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@role='i6header5']">
        <fo:block font-size="12pt" font-weight="bold" padding-top="3pt" margin-top="3pt" text-align-last='justify'
                  white-space-collapse="false">
            <xsl:apply-templates/>
            <fo:leader leader-length.maximum="5pt"/>
            <fo:leader leader-pattern="rule" vertical-align="middle" color="grey"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@role='i6repeatable-header1']">
        <xsl:call-template name="i6label"/>
        <!--<fo:block font-size="16pt" font-weight="bold" padding-top="3pt" margin-top="3pt" white-space-collapse="false">-->
        <!--<xsl:apply-templates/>-->
        <!--</fo:block>-->
    </xsl:template>

    <xsl:template match="*[@role='i6repeatable-header2']">
        <xsl:call-template name="i6label"/>
        <!--<fo:block font-size="15pt" font-weight="bold" padding-top="3pt" margin-top="3pt" white-space-collapse="false">-->
        <!--<xsl:apply-templates/>-->
        <!--</fo:block>-->
    </xsl:template>

    <xsl:template match="*[@role='i6repeatable-header3']">
        <xsl:call-template name="i6label"/>
        <!--<fo:block font-size="14pt" font-weight="bold" padding-top="3pt" margin-top="3pt" white-space-collapse="false">-->
        <!--<xsl:apply-templates/>-->
        <!--</fo:block>-->
    </xsl:template>

    <xsl:template match="*[@role='i6repeatable-header4']">
        <xsl:call-template name="i6label"/>
        <!--<fo:block font-size="13pt" font-weight="bold" padding-top="3pt" margin-top="3pt" white-space-collapse="false">-->
        <!--<xsl:apply-templates/>-->
        <!--</fo:block>-->
    </xsl:template>

    <xsl:template match="*[@role='i6repeatable-header5']">
        <xsl:call-template name="i6label"/>
        <!--<fo:block font-size="12pt" font-weight="bold" padding-top="3pt" margin-top="3pt" white-space-collapse="false">-->
        <!--<xsl:apply-templates/>-->
        <!--</fo:block>-->
    </xsl:template>

    <xsl:template match="*[@role='i6repeatable-entry']">
        <fo:block border="0.5pt solid grey" padding="3pt" margin="0mm" keep-with-next.within-page="10"
                  keep-together.within-page="10">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
	
	<xsl:template match="*[@role='StartMargins']">
        <fo:block space-before="0.8em" start-indent="2px" keep-with-next.within-page="always">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
	
	<xsl:template match="*[@role='SecondMargins']">
        <fo:block space-before="0.10em" start-indent="40px" padding-top="1.0pt" keep-with-next.within-page="always">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
	
	<xsl:template match="*[@role='FirstMargins']">
        <fo:block space-before="0.5em" start-indent="25px" keep-with-next.within-page="always">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
	
	<xsl:template match="*[@role='ThirdMargins']">
        <fo:block space-before="0.10em" start-indent="55px" keep-with-next.within-page="always">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@role='i6label']">
        <xsl:call-template name="i6label"/>
    </xsl:template>

    <xsl:template name="i6label">
        <fo:block font-weight="bold" font-size="10pt" keep-with-next.within-page="always">
            <xsl:value-of select='text()'/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@role='i6LiteralText']">
        <fo:block wrap-option="wrap" hyphenate="false" white-space-collapse="false" white-space-treatment="preserve"
                  linefeed-treatment="preserve" text-align="left">
            <xsl:value-of select='text()'/>
        </fo:block>
    </xsl:template>
	
	<xsl:template match="d:phrase[@role='red']">
		<fo:inline color="red">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="d:phrase[@role='blue']">
		<fo:inline color="blue">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="d:phrase[@role='green']">
		<fo:inline color="green">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="d:phrase[@role='purple']">
		<fo:inline color="purple">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="d:phrase[@role='black']">
		<fo:inline color="black">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="d:phrase[@role='F0E7E7']">
		<fo:inline color="F0E7E7">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="d:phrase[@role='#2a7d33']">
		<fo:inline color="#2a7d33">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="d:phrase[@role='#422a7d']">
		<fo:inline color="#422a7d">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="d:phrase[@role='#7d2a34']">
		<fo:inline color="#7d2a34">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="d:phrase[@role='#2b497d']">
		<fo:inline color="#2b497d">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="d:phrase[@role='#bacbe8']">
		<fo:inline color="#bacbe8">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="d:phrase[@role='#7d0000']">
		<fo:inline color="#7d0000">
		  <xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	
    <!-- Handle tables-->
    <xsl:template name="make-html-table-columns">
        <xsl:param name="count" select="0"/>
        <xsl:param name="number" select="1"/>
   
        <xsl:choose>
            <xsl:when test="d:col|d:colgroup/d:col">
                <xsl:for-each select="d:col|d:colgroup/d:col">
                    <fo:table-column>
                        <xsl:attribute name="column-number">
                            <xsl:number from="d:table|d:informaltable" level="any" format="1"/>
                        </xsl:attribute>
                        <xsl:if test="@width">
                            <xsl:attribute name="column-width">
                                <xsl:choose>
                                    <xsl:when test="contains(@width, '%')">
                                        <xsl:value-of select="concat('proportional-column-width(',
		                                               substring-before(@width, '%'),
		                                               ')')"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="@width"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:attribute>
                        </xsl:if>
                    </fo:table-column>
                </xsl:for-each>
            </xsl:when>
            <xsl:when test="$fop.extensions != 0">
                <xsl:if test="$number &lt;= $count">
                    <fo:table-column column-number="{$number}"
                                     column-width="{6.5 div $count}in"/>
                    <xsl:call-template name="make-html-table-columns">
                        <xsl:with-param name="count" select="$count"/>
                        <xsl:with-param name="number" select="$number + 1"/>
                    </xsl:call-template>
                </xsl:if>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <!-- Handle HEAD-WoutNo role -->
    <xsl:template match="*[@role='HEAD-WoutNo']">
        <fo:inline text-decoration="underline" font-weight="bold" font-size="small">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <!-- Handle indent role-->
    <xsl:template match="*[@role='indent']">
        <fo:block space-before="0.4em" start-indent="14px">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <!-- Handle ignoreIfEmpty role-->
    <xsl:template match="*[@role='ignoreIfEmpty']">
        <xsl:if test="normalize-space(./text()) != ''">
            <fo:block>
                <xsl:apply-templates/>
            </fo:block>
        </xsl:if>
    </xsl:template>

    <!-- Handle color attribute-->
    <xsl:template match="*[@color]">
        <xsl:variable name="color" select="@color"/>
        <xsl:element name="fo:inline">
            <xsl:attribute name="color">
                <xsl:value-of select="$color"/>
            </xsl:attribute>
            <xsl:apply-templates/>
        </xsl:element>
    </xsl:template>
	
	<xsl:template name="table.row.properties">

	  <xsl:variable name="tabstyle">
		<xsl:call-template name="tabstyle"/>
	  </xsl:variable>

	  <xsl:variable name="bgcolor">
		<xsl:call-template name="dbfo-attribute">
		  <xsl:with-param name="pis" select="processing-instruction('dbfo')"/>
		  <xsl:with-param name="attribute" select="'bgcolor'"/>
		</xsl:call-template>
	  </xsl:variable>
	  
	  <xsl:variable name="rownum">
		<xsl:number from="tgroup" count="row"/>
	  </xsl:variable>

	  <xsl:choose>
		<xsl:when test="$bgcolor != ''">
		  <xsl:attribute name="background-color">
			<xsl:value-of select="$bgcolor"/>
		  </xsl:attribute>
		</xsl:when>
		<xsl:when test="$tabstyle = 'striped'">
		  <xsl:if test="$rownum mod 2 = 0">
			<xsl:attribute name="background-color">#EEEEEE</xsl:attribute>
		  </xsl:if>
		</xsl:when>
	  </xsl:choose>
	  
	  <xsl:choose>
		<xsl:when test="$bgcolor != ''">
		  <xsl:attribute name="background-color">
			<xsl:value-of select="$bgcolor"/>
		  </xsl:attribute>
		</xsl:when>
		<xsl:when test="$tabstyle = 'striped'">
		  <xsl:if test="$rownum mod 2 = 0">
			<xsl:attribute name="background-color">#FFA500</xsl:attribute>
		  </xsl:if>
		</xsl:when>
	  </xsl:choose>
	  
	  <xsl:choose>
		<xsl:when test="$bgcolor != ''">
		  <xsl:attribute name="background-color">
			<xsl:value-of select="$bgcolor"/>
		  </xsl:attribute>
		</xsl:when>
		<xsl:when test="$tabstyle = 'striped'">
		  <xsl:if test="$rownum mod 2 = 0">
			<xsl:attribute name="background-color">#4169E1</xsl:attribute>
		  </xsl:if>
		</xsl:when>
	  </xsl:choose>
	  
	  <xsl:choose>
		<xsl:when test="$bgcolor != ''">
		  <xsl:attribute name="background-color">
			<xsl:value-of select="$bgcolor"/>
		  </xsl:attribute>
		</xsl:when>
		<xsl:when test="$tabstyle = 'striped'">
		  <xsl:if test="$rownum mod 2 = 0">
			<xsl:attribute name="background-color">#d6eaf8</xsl:attribute>
		  </xsl:if>
		</xsl:when>
	  </xsl:choose>
	  
	  <xsl:choose>
		<xsl:when test="$bgcolor != ''">
		  <xsl:attribute name="background-color">
			<xsl:value-of select="$bgcolor"/>
		  </xsl:attribute>
		</xsl:when>
		<xsl:when test="$tabstyle = 'striped'">
		  <xsl:if test="$rownum mod 2 = 0">
			<xsl:attribute name="background-color">#87CEFA</xsl:attribute>
		  </xsl:if>
		</xsl:when>
	  </xsl:choose>
	  
	  <xsl:choose>
		<xsl:when test="$bgcolor != ''">
		  <xsl:attribute name="background-color">
			<xsl:value-of select="$bgcolor"/>
		  </xsl:attribute>
		</xsl:when>
		<xsl:when test="$tabstyle = 'striped'">
		  <xsl:if test="$rownum mod 2 = 0">
			<xsl:attribute name="background-color">#87CEFA</xsl:attribute>
		  </xsl:if>
		</xsl:when>
	  </xsl:choose>
	  
	  <xsl:choose>
		<xsl:when test="$bgcolor != ''">
		  <xsl:attribute name="background-color">
			<xsl:value-of select="$bgcolor"/>
		  </xsl:attribute>
		</xsl:when>
		<xsl:when test="$tabstyle = 'striped'">
		  <xsl:if test="$rownum mod 2 = 0">
			<xsl:attribute name="background-color">#A9A9A9</xsl:attribute>
		  </xsl:if>
		</xsl:when>
	  </xsl:choose>
	  
	 </xsl:template>


    <!-- Handle style attribute for background color-->
    <xsl:template match="*[@style]">
        <xsl:variable name="style" select="@style"/>
        <xsl:choose>
            <xsl:when test="contains($style,'background-color:')">
                <xsl:element name="fo:inline">
                    <xsl:attribute name="background-color">
                        <xsl:value-of select="substring($style,18,7)"/>
                    </xsl:attribute>
                    <xsl:apply-templates/>
                </xsl:element>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
	

  	<!-- copied from fo-external-image template in graphics.xsl in order to properly link external urls in rtf -->	
	<xsl:template name="fo-external-url">
		<xsl:param name="filename" />
	
		<xsl:choose>
			<xsl:when test="$fop.extensions != 0">
				<xsl:value-of select="$filename" />
			</xsl:when>
			<xsl:when test="starts-with($filename, 'http://') or starts-with($filename, 'https://') or 
								starts-with($filename, 'HTTP://') or starts-with($filename, 'HTTPS://')">
				<xsl:value-of select="$filename" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="concat('url(', $filename, ')')" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- overriding template from xref.xsl in order to properly link external urls in rtf -->
	<xsl:template match="d:ulink" name="ulink">
	  <xsl:param name="url" select="@url"/>
	
		<xsl:variable name="ulink.url">
			<xsl:call-template name="fo-external-url">
				<xsl:with-param name="filename" select="$url" />
			</xsl:call-template>
		</xsl:variable>
	
		<fo:basic-link xsl:use-attribute-sets="xref.properties"
			external-destination="{$ulink.url}">
			<xsl:choose>
				<xsl:when test="count(child::node())=0 or (string(.) = $url)">
					<fo:inline hyphenate="false">
						<xsl:call-template name="hyphenate-url">
							<xsl:with-param name="url" select="$url" />
						</xsl:call-template>
					</fo:inline>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates />
				</xsl:otherwise>
			</xsl:choose>
		</fo:basic-link>
		<!-- * Call the template for determining whether the URL for this -->
		<!-- * hyperlink is displayed, and how to display it (either inline or -->
		<!-- * as a numbered footnote). -->
		<xsl:call-template name="hyperlink.url.display">
			<xsl:with-param name="url" select="$url" />
			<xsl:with-param name="ulink.url" select="$ulink.url" />
		</xsl:call-template>
	</xsl:template>

</xsl:stylesheet>
